@@ -27,7 +27,7 @@ using namespace KCalCore;
 namespace KAlarmCal
 {
 
-class Repetition::Private
+class Q_DECL_HIDDEN Repetition::Private
 {
 public:
     Private() : mInterval(0), mCount(0) {}
@@ -147,14 +147,14 @@ int Repetition::nextRepeatCount(const KDateTime &from, const KDateTime &preDateT
 {
     return d->mInterval.isDaily()
            ? from.daysTo(preDateTime) / d->mInterval.asDays() + 1
-           : static_cast<int>(from.secsTo_long(preDateTime) / d->mInterval.asSeconds()) + 1;
+           : static_cast<int>(from.secsTo(preDateTime) / d->mInterval.asSeconds()) + 1;
 }
 
 int Repetition::previousRepeatCount(const KDateTime &from, const KDateTime &afterDateTime) const
 {
     return d->mInterval.isDaily()
            ? from.daysTo(afterDateTime.addSecs(-1)) / d->mInterval.asDays()
-           : static_cast<int>((from.secsTo_long(afterDateTime) - 1) / d->mInterval.asSeconds());
+           : static_cast<int>((from.secsTo(afterDateTime) - 1) / d->mInterval.asSeconds());
 }
 
 } // namespace KAlarmCal
